@@ -65,6 +65,8 @@ from .sendfiles import vipergroupactivate
     
 from .sendfiles import vipergroupdeactivate
 
+from .sendfiles import viperanomalytrain
+from .sendfiles import viperanomalypredict
 
 from .callmas import dotraining
 from .callmas import dopredictions
