@@ -166,12 +166,11 @@ def vipersubscribeconsumer(vipertoken,host,port,topic,companyname,contactname,co
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperdeletetopics(vipertoken,host,port,topic,microserviceid=''):
-
-    if len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0:
+def viperdeletetopics(vipertoken,host,port,topic,enabletls=1,brokerhost='',brokerport=9092,microserviceid=''):
+    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0  ):
          return "Please enter host,port,vipertoken,topic"
         
-    value=("deletetopics?vipertoken="+vipertoken + "&topic="+topic)
+    value=("deletetopics?vipertoken="+vipertoken + "&topic="+topic +"&enabletls="+str(enabletls) +"&brokerhost="+brokerhost+"&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
@@ -420,12 +419,12 @@ def vipermodifyconsumerdetails(vipertoken,host,port,topic,companyname,consumerid
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def vipermodifytopicdetails(vipertoken,host,port,topic,companyname,isgroup=0,contactname='',contactemail='',location='',brokerhost='',brokerport=9092,microserviceid=''):
+def vipermodifytopicdetails(vipertoken,host,port,topic,companyname,partition=0,enabletls=1,isgroup=0,contactname='',contactemail='',location='',brokerhost='',brokerport=9092,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(companyname)==0 or len(topic)==0):
          return "Please enter host,port,topic,vipertoken,consumerid,companyname"
         
     value=("modifytopicdetails?vipertoken="+vipertoken + "&topic="+topic +"&brokerhost="+brokerhost+"&brokerport="+str(brokerport)
-          + "&isgroup=" + str(isgroup)  +"&companyname="+companyname+"&contactname="+contactname+"&contactemail="+contactemail+"&location="+location)
+          + "&isgroup=" + str(isgroup) +"&partition="+str(partition) +"&enabletls="+str(enabletls)+"&companyname="+companyname+"&contactname="+contactname+"&contactemail="+contactemail+"&location="+location)
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
